import React, { useState, useEffect, useRef } from 'react';
import { 
  login, 
  register, 
  logout, 
  addScore, 
  getUserScores, 
  deleteScore, 
  getUserStats, 
  getLeaderboard,
  getAllScores,
  connectToWebSocket,
  disconnectFromWebSocket,
  addWebSocketListener,
  removeWebSocketListener
} from './api';

const FramedScoreTracker = () => {
  // État pour gérer le thème
  const [theme, setTheme] = useState("cinema"); // Default to our new cinema theme

  // État pour gérer le joueur actif
  const [activePlayer, setActivePlayer] = useState(null);
  const [playerName, setPlayerName] = useState("");
  const [playerPassword, setPlayerPassword] = useState("");
  const [isRegistering, setIsRegistering] = useState(false);
  const [loginError, setLoginError] = useState("");
  const [isLoading, setIsLoading] = useState(false);
  
  // États pour les jeux et les scores
  const [scores, setScores] = useState([]);
  const [stats, setStats] = useState({});
  const [leaderboard, setLeaderboard] = useState([]);
  const [allScores, setAllScores] = useState([]);
  const [showAllScores, setShowAllScores] = useState(false);
  
  const [newScore, setNewScore] = useState({
    date: new Date().toISOString().split('T')[0],
    gameType: "daily",
    gameNumber: "",
    score: "",
    comment: ""
  });

  

  // Charger le classement
  const loadLeaderboard = async (gameType) => {
    setIsLoading(true);
    try {
      const data = await getLeaderboard(gameType);
      setLeaderboard(data);
    } catch (error) {
      console.error("Erreur lors du chargement du classement:", error);
    } finally {
      setIsLoading(false);
    }
  };
  
  // Charger tous les scores
  const loadAllScores = async (gameType = 'all') => {
    setIsLoading(true);
    try {
      const data = await getAllScores(gameType);
      setAllScores(data);
    } catch (error) {
      console.error("Erreur lors du chargement de tous les scores:", error);
    } finally {
      setIsLoading(false);
    }
  };
  
  const [filterType, setFilterType] = useState("all");

  // Calculer le numéro de jeu selon la date
  const calculateGameNumber = (dateStr, gameType) => {
    // Dates de référence et numéros correspondants
    const referenceDaily = {
      date: new Date('2025-03-04'), // Le jeu Daily Frame #1089 était le 4 mars 2025
      number: 1089
    };
    
    const referenceOne = {
      date: new Date('2025-03-04'), // Le jeu One Frame #92 était le 4 mars 2025
      number: 92
    };
    
    const targetDate = new Date(dateStr);
    
    // Normaliser les dates pour comparer uniquement les jours
    const normalizeDate = (date) => {
      const d = new Date(date);
      d.setHours(0, 0, 0, 0);
      return d;
    };
    
    const normalizedTarget = normalizeDate(targetDate);
    const normalizedReference = normalizeDate(gameType === 'daily' ? referenceDaily.date : referenceOne.date);
    
    // Calculer la différence en jours (en tenant compte des fuseaux horaires)
    const diffTime = normalizedTarget - normalizedReference;
    const diffDays = Math.round(diffTime / (1000 * 60 * 60 * 24));
    
    // Ajouter la différence au numéro de référence
    return (gameType === 'daily' ? referenceDaily.number : referenceOne.number) + diffDays;
  };

  // Grouper les scores par jeu
  const groupScoresByGame = (scores) => {
    const grouped = {};
    
    scores.forEach(score => {
      const gameKey = `${score.game_type}-${score.game_number}`;
      if (!grouped[gameKey]) {
        grouped[gameKey] = {
          gameType: score.game_type,
          gameNumber: score.game_number,
          scores: []
        };
      }
      
      grouped[gameKey].scores.push({
        id: score.id,
        userId: score.user_id,
        username: score.username,
        score: score.score,
        comment: score.comment
      });
    });
    
    // Convertir en tableau et trier par type de jeu et numéro
    return Object.values(grouped).sort((a, b) => {
      if (a.gameType !== b.gameType) {
        return a.gameType === 'daily' ? -1 : 1;
      }
      return b.gameNumber - a.gameNumber;
    });
  };

  // Chargement initial
  useEffect(() => {
    // Charger le thème
    const savedTheme = localStorage.getItem('framedTheme');
    if (savedTheme) {
      setTheme(savedTheme);
    }
    
    // Vérifier si un utilisateur est déjà connecté
    const savedUser = localStorage.getItem('framedUser');
    if (savedUser) {
      const user = JSON.parse(savedUser);
      setActivePlayer(user);
      loadUserData(user.userId);
    }
    
    // Initialiser le score avec le numéro du jour
    const today = new Date().toISOString().split('T')[0];
    const dailyNumber = calculateGameNumber(today, 'daily');
    setNewScore(prev => ({
      ...prev,
      date: today,
      gameNumber: dailyNumber.toString()
    }));
    
    // Charger le classement même sans connexion
    loadLeaderboard('all');
    
    // Établir la connexion WebSocket
    connectToWebSocket();
    
    // Configurer les écouteurs d'événements WebSocket
    const handleNewScore = (data) => {
      console.log('Nouveau score reçu via WebSocket:', data);
      // Recharger les données pertinentes
      if (activePlayer) {
        loadUserData(activePlayer.userId);
      }
      loadLeaderboard(filterType);
      if (showAllScores) {
        loadAllScores(filterType);
      }
    };
    
    const handleDeleteScore = (data) => {
      console.log('Score supprimé via WebSocket:', data);
      // Recharger les données pertinentes
      if (activePlayer) {
        loadUserData(activePlayer.userId);
      }
      loadLeaderboard(filterType);
      if (showAllScores) {
        loadAllScores(filterType);
      }
    };
    
    addWebSocketListener('new-score', handleNewScore);
    addWebSocketListener('delete-score', handleDeleteScore);
    
    // Nettoyer la connexion WebSocket lors du démontage du composant
    return () => {
      removeWebSocketListener('new-score', handleNewScore);
      removeWebSocketListener('delete-score', handleDeleteScore);
      disconnectFromWebSocket();
    };
  }, []);
  
  // Charger tous les scores quand on active la vue
  useEffect(() => {
    if (showAllScores && allScores.length === 0) {
      loadAllScores(filterType);
    }
  }, [showAllScores, filterType]);
  
  // Mettre à jour les écouteurs WebSocket quand activePlayer ou filterType changent
  useEffect(() => {
    // Supprimer les anciens écouteurs
    removeWebSocketListener('new-score', () => {});
    removeWebSocketListener('delete-score', () => {});
    
    // Ajouter les nouveaux écouteurs avec les valeurs à jour
    const handleNewScore = (data) => {
      // Recharger les données pertinentes
      if (activePlayer) {
        loadUserData(activePlayer.userId);
      }
      loadLeaderboard(filterType);
      if (showAllScores) {
        loadAllScores(filterType);
      }
    };
    
    const handleDeleteScore = (data) => {
      // Recharger les données pertinentes
      if (activePlayer) {
        loadUserData(activePlayer.userId);
      }
      loadLeaderboard(filterType);
      if (showAllScores) {
        loadAllScores(filterType);
      }
    };
    
    addWebSocketListener('new-score', handleNewScore);
    addWebSocketListener('delete-score', handleDeleteScore);
    
  }, [activePlayer, filterType, showAllScores]);

  // Sauvegarder le thème
  useEffect(() => {
    localStorage.setItem('framedTheme', theme);
  }, [theme]);

  
  // Changer le thème
  const changeTheme = (newTheme) => {
    setTheme(newTheme);
  };

  // Obtenir les classes CSS basées sur le thème
  const getThemeClasses = () => {
    switch (theme) {
      case 'cinema':
        return {
          app: "bg-black text-gray-100 font-sans",
          card: "bg-zinc-900 border border-amber-500/20 shadow-lg shadow-amber-500/10 backdrop-filter backdrop-blur-sm",
          input: "bg-zinc-800 border-amber-500/30 text-gray-100 focus:border-amber-400 placeholder-gray-500 focus:ring-1 focus:ring-amber-500",
          button: "bg-amber-600 hover:bg-amber-700 text-black font-bold transition-all duration-300 shadow-md hover:shadow-amber-500/20",
          secondaryButton: "bg-zinc-800 hover:bg-zinc-700 text-amber-400 border border-amber-500/30 hover:border-amber-400 transition-all duration-300",
          dangerButton: "text-red-400 hover:text-red-300 transition-all duration-300",
          table: {
            header: "bg-zinc-800 text-amber-400 border-b border-amber-500/20",
            row: "border-b border-zinc-800 hover:bg-zinc-800/50 transition-colors duration-300",
            highlightRow: "bg-amber-900/20 border-b border-amber-500/30",
            activeRow: "bg-zinc-800/80 border-l-2 border-l-amber-500"
          }
        };
      case 'dark':
        return {
          app: "bg-gray-900 text-gray-100",
          card: "bg-gray-800 shadow-md border-gray-700",
          input: "bg-gray-700 border-gray-600 text-white",
          button: "bg-blue-600 hover:bg-blue-700 text-white",
          secondaryButton: "bg-gray-600 hover:bg-gray-700 text-white",
          dangerButton: "text-red-400 hover:text-red-300",
          table: {
            header: "bg-gray-700",
            row: "border-gray-700",
            highlightRow: "bg-gray-700",
            activeRow: "bg-blue-900"
          }
        };
      case 'matrix':
        return {
          app: "bg-black text-green-400 font-mono",
          card: "bg-black border border-green-500 shadow-lg shadow-green-500/20",
          input: "bg-black border-green-500 text-green-400 focus:border-green-300 placeholder-green-700",
          button: "bg-green-900 hover:bg-green-800 text-green-300 border border-green-500",
          secondaryButton: "bg-black hover:bg-green-900 text-green-400 border border-green-500",
          dangerButton: "text-red-500 hover:text-red-400",
          table: {
            header: "bg-green-900 text-green-200",
            row: "border-green-900",
            highlightRow: "bg-green-900/30",
            activeRow: "bg-green-800/50 border-l-4 border-l-green-400"
          }
        };
      case 'matrix-hardcore':
        return {
          app: "bg-black text-green-500 font-mono animate-pulse",
          card: "bg-black border-2 border-green-500 shadow-xl shadow-green-500/30 animate-[pulse_4s_ease-in-out_infinite] backdrop-blur-sm backdrop-brightness-150 relative overflow-hidden before:absolute before:inset-0 before:bg-gradient-to-b before:from-green-500/5 before:to-transparent before:animate-[pulse_3s_ease-in-out_infinite]",
          input: "bg-black/80 border-2 border-green-400 text-green-400 focus:border-green-300 placeholder-green-700 focus:outline-none focus:ring-2 focus:ring-green-500 focus:animate-none transition-all duration-300 backdrop-blur-sm",
          button: "bg-black hover:bg-green-900/30 text-green-300 border-2 border-green-500 shadow-md shadow-green-500/20 hover:shadow-green-500/40 transition-all duration-300 backdrop-blur-sm hover:animate-pulse relative overflow-hidden before:absolute before:inset-0 before:bg-gradient-to-r before:from-transparent before:via-green-400/10 before:to-transparent before:translate-x-[-200%] hover:before:translate-x-[200%] before:transition-all before:duration-1000",
          secondaryButton: "bg-black/80 hover:bg-green-900/20 text-green-400 border-2 border-green-400 hover:border-green-300 transition-all duration-300 backdrop-blur-sm hover:text-green-300 relative overflow-hidden before:absolute before:inset-0 before:bg-gradient-to-r before:from-transparent before:via-green-400/10 before:to-transparent before:translate-x-[-200%] hover:before:translate-x-[200%] before:transition-all before:duration-1000",
          dangerButton: "text-red-400 hover:text-red-300 hover:animate-pulse transition-all duration-300 relative after:absolute after:bottom-0 after:left-0 after:right-0 after:h-[1px] after:bg-red-500/50 after:scale-x-0 hover:after:scale-x-100 after:transition-transform after:duration-300",
          table: {
            header: "bg-green-900/20 text-green-300 border-b-2 border-green-500/50 backdrop-blur-sm",
            row: "border-b border-green-900/50 hover:bg-green-900/10 transition-colors duration-300",
            highlightRow: "bg-green-900/20 border-b border-green-500/50 animate-[pulse_2s_ease-in-out_infinite] backdrop-blur-sm",
            activeRow: "bg-green-800/30 border-l-4 border-l-green-400 relative overflow-hidden before:absolute before:inset-0 before:bg-gradient-to-r before:from-transparent before:via-green-400/10 before:to-transparent before:animate-[slide_2s_ease-in-out_infinite]"
          }
        };
      default: // standard
        return {
          app: "bg-gray-50 text-gray-800",
          card: "bg-white shadow-md",
          input: "border-gray-300 bg-white",
          button: "bg-blue-500 hover:bg-blue-600 text-white",
          secondaryButton: "bg-gray-300 hover:bg-gray-400 text-gray-800",
          dangerButton: "text-red-500 hover:text-red-700",
          table: {
            header: "bg-gray-100",
            row: "border-t border-gray-200",
            highlightRow: "bg-yellow-50",
            activeRow: "bg-blue-50"
          }
        };
    }
  }

  // Charger les données utilisateur
  const loadUserData = async (userId) => {
    setIsLoading(true);
    try {
      // Charger les scores
      const userScores = await getUserScores(userId);
      setScores(userScores);
      
      // Charger les statistiques
      const userStats = await getUserStats(userId);
      setStats(userStats);
    } catch (error) {
      console.error("Erreur lors du chargement des données:", error);
    } finally {
      setIsLoading(false);
  }

  };
  
  const themeClasses = getThemeClasses();

  // Gérer la connexion/inscription
  const handleLogin = async () => {
    if (!playerName.trim()) {
      setLoginError("Veuillez entrer un nom d'utilisateur");
      return;
    }
    
    if (!playerPassword.trim()) {
      setLoginError("Veuillez entrer un mot de passe");
      return;
    }
    
    setIsLoading(true);
    
    try {
      const user = await login(playerName, playerPassword);
      setActivePlayer(user);
      setLoginError("");
      loadUserData(user.userId);
    } catch (error) {
      setLoginError(error.error || "Erreur de connexion");
    } finally {
      setIsLoading(false);
    }
  };

  const handleRegister = async () => {
    if (!playerName.trim()) {
      setLoginError("Veuillez entrer un nom d'utilisateur");
      return;
    }
    
    if (!playerPassword.trim()) {
      setLoginError("Veuillez entrer un mot de passe");
      return;
    }
    
    setIsLoading(true);
    
    try {
      // Inscription
      await register(playerName, playerPassword);
      
      // Connexion après inscription réussie
      const user = await login(playerName, playerPassword);
      setActivePlayer(user);
      setLoginError("");
    } catch (error) {
      setLoginError(error.error || "Erreur d'inscription");
    } finally {
      setIsLoading(false);
    }
  };

  const handleLogout = () => {
    logout();
    setActivePlayer(null);
    setPlayerName("");
    setPlayerPassword("");
    setScores([]);
    setStats({});
  };

  // Gérer les nouveaux scores
  const handleScoreChange = (e) => {
    const value = e.target.value;
    // Valider que le score est entre 0 et 6, ou vide
    if (value === "" || (parseInt(value) >= 0 && parseInt(value) <= 6)) {
      setNewScore({ ...newScore, score: value });
    }
  };

  const handleGameTypeChange = (e) => {
    const gameType = e.target.value;
    // Calculer automatiquement le numéro du jeu en fonction de la date sélectionnée
    const gameNumber = calculateGameNumber(newScore.date, gameType);
    setNewScore({ ...newScore, gameType, gameNumber: gameNumber.toString() });
  };

  const handleGameNumberChange = (e) => {
    setNewScore({ ...newScore, gameNumber: e.target.value });
  };

  const handleDateChange = (e) => {
    const newDate = e.target.value;
    // Recalculer le numéro du jeu lorsque la date change
    const gameNumber = calculateGameNumber(newDate, newScore.gameType);
    setNewScore({ 
      ...newScore, 
      date: newDate,
      gameNumber: gameNumber.toString()
    });
  };

  const handleFilterChange = (e) => {
    const newFilter = e.target.value;
    setFilterType(newFilter);
    loadLeaderboard(newFilter);
  };

  // Ajouter un score
  const addNewScore = async () => {
    if (!newScore.score) {
      return; // Ne pas ajouter de score vide
    }
    
    setIsLoading(true);
    
    try {
      await addScore(
        activePlayer.userId,
        newScore.date,
        newScore.gameType,
        newScore.gameNumber,
        parseInt(newScore.score),
        newScore.comment
      );
      
      // Recharger les scores et stats
      loadUserData(activePlayer.userId);
      
      // Réinitialiser le formulaire
      const today = new Date().toISOString().split('T')[0];
      const dailyNumber = calculateGameNumber(today, 'daily');
      setNewScore({
        date: today,
        gameType: "daily",
        gameNumber: dailyNumber.toString(),
        score: "",
        comment: ""
      });
      
      // Recharger le classement
      loadLeaderboard(filterType);
    } catch (error) {
      console.error("Erreur lors de l'ajout du score:", error);
    } finally {
      setIsLoading(false);
    }
  };

  // Supprimer un score
  const removeScore = async (scoreId) => {
    if (!activePlayer) return;
    
    setIsLoading(true);
    
    try {
      await deleteScore(scoreId, activePlayer.userId);
      
      // Recharger les données
      loadUserData(activePlayer.userId);
      loadLeaderboard(filterType);
    } catch (error) {
      console.error("Erreur lors de la suppression du score:", error);
    } finally {
      setIsLoading(false);
    }
  };

  // Obtenir les scores filtrés
  const getFilteredScores = () => {
    if (filterType === "all") {
      return scores;
    }
    return scores.filter(score => score.game_type === filterType);
  };
  
  // Special score display for matrix-hardcore theme
  const renderScore = (score) => {
    if (theme !== 'matrix-hardcore') return score;
    
    // For matrix-hardcore theme, make the score more dramatic
    const scoreClass = score <= 2 
      ? "text-green-300 font-bold animate-pulse" 
      : score <= 4 
        ? "text-yellow-400 font-bold" 
        : "text-red-500 font-bold";
        
    return <span className={scoreClass}>{score}</span>;
  };

  const getGameTypeLabel = (type) => {
    return type === "daily" ? "Daily Frame" : "One Frame";
  };

  const getGameIdentifier = (game) => {
    if (game.game_number) {
      return `${getGameTypeLabel(game.game_type)} #${game.game_number}`;
    }
    return getGameTypeLabel(game.game_type);
  };

  // Calculer les statistiques pour l'affichage
  const getStatsByType = (type) => {
    if (!stats || !stats.length) return { average: "-", best: "-", total: 0 };
    
    const typeStat = stats.find(s => s.game_type === type);
    
    if (!typeStat) return { average: "-", best: "-", total: 0 };
    
    return {
      average: typeStat.average_score.toFixed(2),
      best: typeStat.best_score,
      total: typeStat.total_games
    };
  };

  const getAllStats = () => {
    if (!stats || !stats.length) return { average: "-", best: "-", total: 0 };
    
    const totalGames = stats.reduce((sum, s) => sum + s.total_games, 0);
    
    if (totalGames === 0) return { average: "-", best: "-", total: 0 };
    
    const weightedSum = stats.reduce((sum, s) => sum + s.average_score * s.total_games, 0);
    const average = weightedSum / totalGames;
    
    const bestScores = stats.map(s => s.best_score);
    const best = Math.min(...bestScores);
    
    return {
      average: average.toFixed(2),
      best,
      total: totalGames
    };
  };

  // Composant du sélecteur de thème
  const ThemeSelector = () => (
    <div className="absolute top-2 right-2 flex space-x-2 z-10">
      <button
        onClick={() => changeTheme('cinema')}
        className={`px-2 py-1 text-xs rounded ${
          theme === 'cinema'
            ? 'bg-amber-500 text-black font-bold'
            : 'bg-gray-200 text-gray-700 dark:bg-gray-700 dark:text-gray-300'
        }`}
      >
        Cinema
      </button>
      <button
        onClick={() => changeTheme('standard')}
        className={`px-2 py-1 text-xs rounded ${
          theme === 'standard'
            ? 'bg-blue-500 text-white'
            : 'bg-gray-200 text-gray-700 dark:bg-gray-700 dark:text-gray-300'
        }`}
      >
        Standard
      </button>
      <button
        onClick={() => changeTheme('dark')}
        className={`px-2 py-1 text-xs rounded ${
          theme === 'dark'
            ? 'bg-blue-500 text-white'
            : 'bg-gray-200 text-gray-700 dark:bg-gray-700 dark:text-gray-300'
        }`}
      >
        Sombre
      </button>
      <button
        onClick={() => changeTheme('matrix')}
        className={`px-2 py-1 text-xs rounded ${
          theme === 'matrix'
            ? 'bg-green-500 text-black'
            : 'bg-gray-200 text-gray-700 dark:bg-gray-700 dark:text-gray-300'
        }`}
      >
        Matrix
      </button>
      <button
        onClick={() => changeTheme('matrix-hardcore')}
        className={`px-2 py-1 text-xs rounded ${
          theme === 'matrix-hardcore'
            ? 'bg-green-600 text-black animate-pulse'
            : 'bg-gray-200 text-gray-700 dark:bg-gray-700 dark:text-gray-300'
        }`}
      >
        Matrix HC
      </button>
    </div>
  );

  // Cinema theme effects
  const CinemaEffects = () => {
    if (theme !== 'cinema') return null;
    
    return (
      <>
        <div className="film-grain"></div>
        <div className="film-strip"></div>
      </>
    );
  };

  // Code Rain effect for matrix-hardcore theme
  const MatrixCodeRain = () => {
    const canvasRef = useRef(null);
    
    useEffect(() => {
      if (theme !== 'matrix-hardcore') return;
      
      const canvas = canvasRef.current;
      const ctx = canvas.getContext('2d');
      
      // Set canvas size to window size
      canvas.width = window.innerWidth;
      canvas.height = window.innerHeight;
      
      // Characters to display in the rain
      const characters = "01アイウエオカキクケコサシスセソタチツテトナニヌネノハヒフヘホマミムメモヤユヨラリルレロワヲン";
      
      // Array to store the columns
      const columns = [];
      // Size of characters
      const fontSize = 14;
      // Number of columns
      const columnsCount = Math.floor(canvas.width / fontSize);
      
      // Initialize columns to starting positions
      for (let i = 0; i < columnsCount; i++) {
        // Start y position at random points
        columns[i] = Math.random() * -canvas.height;
      }
      
      // The animation loop
      const draw = () => {
        // Slightly transparent black background to show trail effect
        ctx.fillStyle = "rgba(0, 0, 0, 0.05)";
        ctx.fillRect(0, 0, canvas.width, canvas.height);
        
        // Green text
        ctx.fillStyle = "#0f0";
        ctx.font = `${fontSize}px monospace`;
        
        // Loop through each column
        for (let i = 0; i < columnsCount; i++) {
          // Pick a random character
          const char = characters.charAt(Math.floor(Math.random() * characters.length));
          
          // Draw the character
          ctx.fillText(char, i * fontSize, columns[i]);
          
          // Move the column down
          columns[i] += fontSize;
          
          // Random chance to reset the y position of a column
          if (columns[i] > canvas.height && Math.random() > 0.975) {
            columns[i] = 0;
          }
        }
        
        // Call the animation again
        if (theme === 'matrix-hardcore') {
          requestAnimationFrame(draw);
        }
      };
      
      // Start the animation
      const animation = requestAnimationFrame(draw);
      
      // Resize handler
      const handleResize = () => {
        canvas.width = window.innerWidth;
        canvas.height = window.innerHeight;
      };
      
      // Add resize listener
      window.addEventListener('resize', handleResize);
      
      // Cleanup on unmount or theme change
      return () => {
        cancelAnimationFrame(animation);
        window.removeEventListener('resize', handleResize);
      };
    }, [theme]);
    
    if (theme !== 'matrix-hardcore') return null;
    
    return <canvas ref={canvasRef} className="matrix-code-rain" />;
  };

  // Loader pendant le chargement
  const Loader = () => (
    <div className="fixed inset-0 bg-black bg-opacity-50 flex items-center justify-center z-50">
      <div className={`${theme === 'matrix-hardcore' ? 'bg-black border-2 border-green-500' : 'bg-white'} p-4 rounded-lg flex items-center justify-center shadow-lg`}>
        <div className={`animate-spin rounded-full h-8 w-8 border-b-2 ${theme === 'matrix-hardcore' ? 'border-green-500' : 'border-gray-900'} mr-2`}></div>
        <span className={theme === 'matrix-hardcore' ? 'text-green-500 animate-pulse' : ''}>Chargement...</span>
      </div>
    </div>
  );

  // Affichage du formulaire de connexion
  if (!activePlayer) {
    return (
      <div className={`min-h-screen p-4 ${themeClasses.app} ${
        theme === 'matrix-hardcore' 
          ? 'matrix-hardcore-app relative' 
          : theme === 'cinema'
            ? 'cinema-app relative'
            : 'relative'
      }`}>
        {theme === 'matrix-hardcore' && <MatrixCodeRain />}
        {theme === 'cinema' && <CinemaEffects />}
        {isLoading && <Loader />}
        <ThemeSelector />
        
        <div className={`max-w-md mx-auto rounded-lg p-6 mt-10 ${themeClasses.card} relative z-10`}>
          <h1 className={`text-2xl font-bold mb-6 text-center ${
            theme === 'matrix-hardcore' 
              ? 'animate-[flicker_5s_linear_infinite] relative after:content-["Framed_Score_Tracker"] after:absolute after:top-0 after:left-0 after:text-green-300 after:opacity-70 after:animate-[glitch_1s_ease-in-out_infinite] after:translate-x-[-2px] before:content-["Framed_Score_Tracker"] before:absolute before:top-0 before:left-0 before:text-red-500/30 before:animate-[glitch_2s_ease-in-out_infinite] before:translate-x-[2px]'
              : theme === 'cinema'
                ? 'text-amber-400 film-flicker tracking-wider'
                : ''
          }`}>Framed Score Tracker</h1>
          
          <div className="mb-4">
            <label className="block text-sm font-medium mb-1">Nom d'utilisateur</label>
            <input
              type="text"
              value={playerName}
              onChange={(e) => setPlayerName(e.target.value)}
              className={`w-full rounded px-3 py-2 ${themeClasses.input}`}
            />
          </div>
          
          <div className="mb-4">
            <label className="block text-sm font-medium mb-1">Mot de passe</label>
            <input
              type="password"
              value={playerPassword}
              onChange={(e) => setPlayerPassword(e.target.value)}
              className={`w-full rounded px-3 py-2 ${themeClasses.input}`}
            />
          </div>
          
          {loginError && (
            <div className="mb-4 p-2 bg-red-100 text-red-800 rounded dark:bg-red-900 dark:text-red-200">
              {loginError}
            </div>
          )}
          
          <div className="flex space-x-4">
            <button
              onClick={isRegistering ? handleRegister : handleLogin}
              disabled={isLoading}
              className={`flex-1 px-4 py-2 rounded ${themeClasses.button} ${
                isLoading ? 'opacity-50 cursor-not-allowed' : ''
              }`}
            >
              {theme === 'matrix-hardcore' 
                ? (isRegistering ? "REGISTER NEW USER" : "ESTABLISH CONNECTION") 
                : (isRegistering ? "S'inscrire" : "Se connecter")
              }
            </button>
            
            <button
              onClick={() => setIsRegistering(!isRegistering)}
              disabled={isLoading}
              className={`flex-1 px-4 py-2 rounded ${themeClasses.secondaryButton} ${
                isLoading ? 'opacity-50 cursor-not-allowed' : ''
              }`}
            >
              {theme === 'matrix-hardcore'
                ? (isRegistering ? "ACCESS EXISTING PROFILE" : "CREATE NEW IDENTITY")
                : (isRegistering ? "Déjà inscrit ?" : "Créer un compte")
              }
            </button>
          </div>
          
          {/* Affichage du classement global même sans connexion */}
          <div className="mt-8">
            <h2 className="text-xl font-semibold mb-3">Classement Général</h2>
            
            <div className="mb-4">
              <select
                value={filterType}
                onChange={handleFilterChange}
                className={`border rounded px-3 py-2 ${themeClasses.input}`}
              >
                <option value="all">{theme === 'matrix-hardcore' ? "ALL DATA STREAMS" : "Tous les jeux"}</option>
                <option value="daily">{theme === 'matrix-hardcore' ? "DAILY FRAMES ONLY" : "Daily Frame uniquement"}</option>
                <option value="one">{theme === 'matrix-hardcore' ? "ONE FRAMES ONLY" : "One Frame uniquement"}</option>
              </select>
            </div>
            
            {leaderboard.length === 0 ? (
                              <p className="text-gray-500 italic dark:text-gray-400">Aucun score enregistré</p>
              ) : (
              <div className="overflow-x-auto">
                <table className={`w-full rounded ${themeClasses.card}`}>
                  <thead className={themeClasses.table.header}>
                    <tr>
                      <th className="px-4 py-2 text-left">Joueur</th>
                      <th className="px-4 py-2 text-center">Parties</th>
                      <th className="px-4 py-2 text-center">Moyenne</th>
                      <th className="px-4 py-2 text-center">Meilleur</th>
                    </tr>
                  </thead>
                  <tbody>
                    {leaderboard.map((player, index) => (
                      <tr 
                        key={player.id} 
                        className={index === 0 ? themeClasses.table.highlightRow : themeClasses.table.row}
                      >
                        <td className="px-4 py-2">
                          {index === 0 && "🏆 "}
                          {player.username}
                        </td>
                        <td className="px-4 py-2 text-center">{player.total_games}</td>
                        <td className="px-4 py-2 text-center">{player.average_score.toFixed(2)}</td>
                        <td className="px-4 py-2 text-center">{player.best_score}</td>
                      </tr>
                    ))}
                  </tbody>
                </table>
              </div>
            )}
          </div>
        </div>
      </div>
    );
  }

  // Interface principale avec l'utilisateur connecté
  return (
    <div className={`min-h-screen p-4 ${themeClasses.app} ${
      theme === 'matrix-hardcore' 
        ? 'matrix-hardcore-app relative' 
        : theme === 'cinema'
          ? 'cinema-app relative'
          : 'relative'
    }`}>
      {theme === 'matrix-hardcore' && <MatrixCodeRain />}
      {theme === 'cinema' && <CinemaEffects />}
      {isLoading && <Loader />}
      <ThemeSelector />
      
      <div className={`max-w-4xl mx-auto rounded-lg p-6 ${themeClasses.card} relative z-10`}>
        <div className="flex justify-between items-center mb-6">
          <h1 className={`text-2xl font-bold ${
            theme === 'matrix-hardcore' 
              ? 'animate-[flicker_5s_linear_infinite] relative after:content-["Framed_Score_Tracker"] after:absolute after:top-0 after:left-0 after:text-green-300 after:opacity-70 after:animate-[glitch_1s_ease-in-out_infinite] after:translate-x-[-2px] before:content-["Framed_Score_Tracker"] before:absolute before:top-0 before:left-0 before:text-red-500/30 before:animate-[glitch_2s_ease-in-out_infinite] before:translate-x-[2px]'
              : theme === 'cinema'
                ? 'text-amber-400 film-flicker tracking-wider'
                : ''
          }`}>Framed Score Tracker</h1>
          <div>
            <span className="mr-2">Connecté en tant que <strong className={theme === 'matrix-hardcore' ? 'text-green-300' : ''}>{activePlayer.username}</strong></span>
            <button 
              onClick={handleLogout}
              className={`px-3 py-1 rounded text-sm ${themeClasses.secondaryButton}`}
            >
              {theme === 'matrix-hardcore' ? 'EXIT MATRIX' : 'Déconnexion'}
            </button>
          </div>
        </div>
        
        {/* Récapitulatif des statistiques */}
        <div className={`mb-8 p-4 rounded ${themeClasses.card} border ${theme === 'matrix' || theme === 'matrix-hardcore' ? 'border-green-500' : theme === 'cinema' ? 'border-amber-500/30' : 'border-gray-200 dark:border-gray-700'}`}>
          <h2 className="text-xl font-semibold mb-3">Vos statistiques</h2>
          
          <div className="grid grid-cols-3 gap-4">
            <div className={`p-3 rounded border ${theme === 'matrix' || theme === 'matrix-hardcore' ? 'border-green-500' : theme === 'cinema' ? 'border-amber-500/30' : 'border-gray-200 dark:border-gray-700'}`}>
              <h3 className="font-medium text-center mb-2">Tous les jeux</h3>
              <div className="grid grid-cols-2 gap-x-2 gap-y-1 text-sm">
                <span>Moyenne:</span>
                <span className="font-medium">{getAllStats().average}</span>
                <span>Meilleur:</span>
                <span className="font-medium">{getAllStats().best}</span>
                <span>Parties:</span>
                <span className="font-medium">{getAllStats().total}</span>
              </div>
            </div>
            
            <div className={`p-3 rounded border ${theme === 'matrix' || theme === 'matrix-hardcore' ? 'border-green-500' : theme === 'cinema' ? 'border-amber-500/30' : 'border-gray-200 dark:border-gray-700'}`}>
              <h3 className="font-medium text-center mb-2">Daily Frame</h3>
              <div className="grid grid-cols-2 gap-x-2 gap-y-1 text-sm">
                <span>Moyenne:</span>
                <span className="font-medium">{getStatsByType('daily').average}</span>
                <span>Meilleur:</span>
                <span className="font-medium">{getStatsByType('daily').best}</span>
                <span>Parties:</span>
                <span className="font-medium">{getStatsByType('daily').total}</span>
              </div>
            </div>
            
            <div className={`p-3 rounded border ${theme === 'matrix' || theme === 'matrix-hardcore' ? 'border-green-500' : theme === 'cinema' ? 'border-amber-500/30' : 'border-gray-200 dark:border-gray-700'}`}>
              <h3 className="font-medium text-center mb-2">One Frame</h3>
              <div className="grid grid-cols-2 gap-x-2 gap-y-1 text-sm">
                <span>Moyenne:</span>
                <span className="font-medium">{getStatsByType('one').average}</span>
                <span>Meilleur:</span>
                <span className="font-medium">{getStatsByType('one').best}</span>
                <span>Parties:</span>
                <span className="font-medium">{getStatsByType('one').total}</span>
              </div>
            </div>
          </div>
        </div>
        
        {/* Ajout d'un nouveau score */}
        <div className={`mb-8 p-4 rounded ${themeClasses.card} border ${theme === 'matrix' || theme === 'matrix-hardcore' ? 'border-green-500' : theme === 'cinema' ? 'border-amber-500/30' : 'border-gray-200 dark:border-gray-700'}`}>
          <h2 className="text-xl font-semibold mb-3">Ajouter un score</h2>
          
          <div className="grid grid-cols-1 md:grid-cols-3 gap-4 mb-4">
            <div>
              <label className="block text-sm font-medium mb-1">Type de jeu</label>
              <select
                value={newScore.gameType}
                onChange={handleGameTypeChange}
                className={`w-full rounded px-3 py-2 ${themeClasses.input}`}
              >
                <option value="daily">{theme === 'matrix-hardcore' ? "DAILY FRAME" : "Daily Frame"}</option>
                <option value="one">{theme === 'matrix-hardcore' ? "ONE FRAME" : "One Frame"}</option>
              </select>
            </div>
            
            <div>
              <label className="block text-sm font-medium mb-1">Numéro du jeu</label>
              <input
                type="number"
                value={newScore.gameNumber}
                onChange={handleGameNumberChange}
                placeholder="ex: 1088 ou 91"
                className={`w-full rounded px-3 py-2 ${themeClasses.input}`}
              />
            </div>
            
            <div>
              <label className="block text-sm font-medium mb-1">Votre score (0-6)</label>
              <input
                type="number"
                min="0"
                max="6"
                value={newScore.score}
                onChange={handleScoreChange}
                placeholder="0-6"
                className={`w-full rounded px-3 py-2 ${themeClasses.input}`}
              />
            </div>
          </div>
          
          <div className="mb-4">
            <label className="block text-sm font-medium mb-1">Commentaire (optionnel)</label>
            <input
              type="text"
              value={newScore.comment || ""}
              onChange={(e) => setNewScore({ ...newScore, comment: e.target.value })}
              placeholder="ex: Film à voir absolument !"
              className={`w-full rounded px-3 py-2 ${themeClasses.input}`}
            />
          </div>
          
          <button
            onClick={addNewScore}
            disabled={!newScore.score || isLoading}
            className={`px-4 py-2 rounded ${
              newScore.score && !isLoading
                ? themeClasses.button
                : "bg-gray-300 text-gray-500 dark:bg-gray-700 dark:text-gray-400 cursor-not-allowed"
            }`}
          >
            {theme === 'matrix-hardcore' ? "UPLOAD SCORE TO MATRIX" : "Ajouter ce score"}
          </button>
        </div>
        
        {/* Historique des scores */}
        <div>
          <div className="flex justify-between items-center mb-3">
            <h2 className="text-xl font-semibold">Historique de vos scores</h2>
            
            <select
              value={filterType}
              onChange={handleFilterChange}
              className={`rounded px-3 py-2 ${themeClasses.input}`}
            >
              <option value="all">{theme === 'matrix-hardcore' ? "ALL DATA STREAMS" : "Tous les jeux"}</option>
              <option value="daily">{theme === 'matrix-hardcore' ? "DAILY FRAMES ONLY" : "Daily Frame uniquement"}</option>
              <option value="one">{theme === 'matrix-hardcore' ? "ONE FRAMES ONLY" : "One Frame uniquement"}</option>
            </select>
          </div>
          
          {getFilteredScores().length === 0 ? (
            <p className="text-gray-500 italic dark:text-gray-400">Aucun score enregistré</p>
          ) : (
            <div className="overflow-x-auto">
              <table className={`w-full rounded ${themeClasses.card}`}>
                <thead className={themeClasses.table.header}>
                  <tr>
                    <th className="px-4 py-2 text-left">Date</th>
                    <th className="px-4 py-2 text-left">Jeu</th>
                    <th className="px-4 py-2 text-center">Score</th>
                    <th className="px-4 py-2 text-left">Commentaire</th>
                    <th className="px-4 py-2"></th>
                  </tr>
                </thead>
                <tbody>
                  {getFilteredScores().sort((a, b) => new Date(b.date) - new Date(a.date)).map(score => (
                    <tr key={score.id} className={themeClasses.table.row}>
                      <td className="px-4 py-2">{new Date(score.date).toLocaleDateString()}</td>
                      <td className="px-4 py-2">{getGameIdentifier(score)}</td>
                      <td className="px-4 py-2 text-center">{renderScore(score.score)}</td>
                      <td className="px-4 py-2">{score.comment}</td>
                      <td className="px-4 py-2 text-right">
                        <button
                          onClick={() => removeScore(score.id)}
                          disabled={isLoading}
                          className={themeClasses.dangerButton}
                        >
                          {theme === 'matrix-hardcore' ? 'TERMINATE' : 'Supprimer'}
                        </button>
                      </td>
                    </tr>
                  ))}
                </tbody>
              </table>
            </div>
          )}
        </div>
        
        {/* Bouton pour afficher tous les scores */}
        <div className="mt-8 mb-4 flex justify-between items-center">
          <button
            onClick={() => {
              setShowAllScores(!showAllScores);
              if (!showAllScores && allScores.length === 0) {
                loadAllScores(filterType);
              }
            }}
            className={`px-4 py-2 rounded ${themeClasses.secondaryButton}`}
          >
            {showAllScores 
              ? (theme === 'matrix-hardcore' ? "RETURN TO DASHBOARD" : "Retour au tableau de bord") 
              : (theme === 'matrix-hardcore' ? "VIEW ALL FRAMES DATA" : "Voir tous les scores par frame")
            }
          </button>
        </div>
        
        {/* Affichage de tous les scores par frame */}
        {showAllScores ? (
          <div className="mt-4">
            <h2 className="text-xl font-semibold mb-3">Tous les scores par frame</h2>
            
            <div className="mb-4">
              <select
                value={filterType}
                onChange={(e) => {
                  const newFilter = e.target.value;
                  setFilterType(newFilter);
                  loadAllScores(newFilter);
                }}
                className={`rounded px-3 py-2 ${themeClasses.input}`}
              >
                <option value="all">{theme === 'matrix-hardcore' ? "ALL DATA STREAMS" : "Tous les jeux"}</option>
                <option value="daily">{theme === 'matrix-hardcore' ? "DAILY FRAMES ONLY" : "Daily Frame uniquement"}</option>
                <option value="one">{theme === 'matrix-hardcore' ? "ONE FRAMES ONLY" : "One Frame uniquement"}</option>
              </select>
            </div>
            
            {allScores.length === 0 ? (
              <p className="text-gray-500 italic dark:text-gray-400">Aucun score enregistré</p>
            ) : (
              <div>
                {groupScoresByGame(allScores).map(game => (
                  <div key={`${game.gameType}-${game.gameNumber}`} className={`mb-6 p-4 rounded ${themeClasses.card} border ${theme === 'matrix' || theme === 'matrix-hardcore' ? 'border-green-500' : theme === 'cinema' ? 'border-amber-500/30' : 'border-gray-200 dark:border-gray-700'}`}>
                    <h3 className="text-lg font-semibold mb-3">
                      {getGameTypeLabel(game.gameType)} #{game.gameNumber}
                    </h3>
                    
                    <div className="overflow-x-auto">
                      <table className={`w-full rounded ${themeClasses.card}`}>
                        <thead className={themeClasses.table.header}>
                          <tr>
                            <th className="px-4 py-2 text-left">Joueur</th>
                            <th className="px-4 py-2 text-center">Score</th>
                            <th className="px-4 py-2 text-left">Commentaire</th>
                          </tr>
                        </thead>
                        <tbody>
                          {game.scores.sort((a, b) => a.score - b.score).map(score => {
                            const isCurrentPlayer = score.userId === activePlayer.userId;
                            let rowClass = themeClasses.table.row;
                            
                            if (isCurrentPlayer) rowClass = themeClasses.table.activeRow;
                            
                            return (
                              <tr key={score.id} className={rowClass}>
                                <td className="px-4 py-2">
                                  <span className={isCurrentPlayer && theme === 'matrix-hardcore' ? 'text-green-300 font-bold' : ''}>
                                    {score.username}
                                    {isCurrentPlayer && ` ${theme === 'matrix-hardcore' ? '[USER]' : '(vous)'}`}
                                  </span>
                                </td>
                                <td className="px-4 py-2 text-center">{renderScore(score.score)}</td>
                                <td className="px-4 py-2">{score.comment}</td>
                              </tr>
                            );
                          })}
                        </tbody>
                      </table>
                    </div>
                  </div>
                ))}
              </div>
            )}
          </div>
        ) : (
          <div className="mt-4">
            <h2 className="text-xl font-semibold mb-3">Classement Général</h2>
          
            {leaderboard.length === 0 ? (
              <p className="text-gray-500 italic dark:text-gray-400">Aucun score enregistré</p>
            ) : (
              <div className="overflow-x-auto">
                <table className={`w-full rounded ${themeClasses.card}`}>
                  <thead className={themeClasses.table.header}>
                    <tr>
                      <th className="px-4 py-2 text-left">Joueur</th>
                      <th className="px-4 py-2 text-center">Parties</th>
                      <th className="px-4 py-2 text-center">Moyenne</th>
                      <th className="px-4 py-2 text-center">Meilleur</th>
                    </tr>
                  </thead>
                  <tbody>
                    {leaderboard.map((player, index) => {
                      const isCurrentPlayer = player.id === activePlayer.userId;
                      let rowClass = themeClasses.table.row;
                      
                      if (index === 0) rowClass = themeClasses.table.highlightRow;
                      if (isCurrentPlayer) rowClass = themeClasses.table.activeRow;
                      
                      // Special trophy for matrix-hardcore theme
                      const trophy = theme === 'matrix-hardcore' 
                        ? "👑" 
                        : "🏆";
                        
                      return (
                        <tr key={player.id} className={rowClass}>
                          <td className="px-4 py-2">
                            {index === 0 && <span className={theme === 'matrix-hardcore' ? 'animate-pulse' : ''}>{trophy} </span>}
                            <span className={isCurrentPlayer && theme === 'matrix-hardcore' ? 'text-green-300 font-bold' : ''}>
                              {player.username}
                              {isCurrentPlayer && ` ${theme === 'matrix-hardcore' ? '[USER]' : '(vous)'}`}
                            </span>
                          </td>
                          <td className="px-4 py-2 text-center">{player.total_games}</td>
                          <td className="px-4 py-2 text-center">{player.average_score.toFixed(2)}</td>
                          <td className="px-4 py-2 text-center">{renderScore(player.best_score)}</td>
                        </tr>
                      );
                    })}
                  </tbody>
                </table>
              </div>
            )}
          </div>
        )}
      </div>
    </div>
  );
};

export default FramedScoreTracker;
